==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/TypicalPriceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { TypicalPriceIndicatorStrategy } from "./TypicalPriceIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var TypicalPriceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TypicalPriceIndicator, _super);
    function TypicalPriceIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TypicalPriceIndicator.prototype.get_up = function () {
        return new TypicalPriceIndicatorStrategy();
    };
    Object.defineProperty(TypicalPriceIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    TypicalPriceIndicator.prototype.get_u2 = function () {
        return TypicalPriceIndicator.$;
    };
    Object.defineProperty(TypicalPriceIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    TypicalPriceIndicator.$t = markType(TypicalPriceIndicator, 'TypicalPriceIndicator', StrategyBasedIndicator.$);
    return TypicalPriceIndicator;
}(StrategyBasedIndicator));
export { TypicalPriceIndicator };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/TypicalPriceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { TypicalPriceIndicatorStrategy } from "./TypicalPriceIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var TypicalPriceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TypicalPriceIndicator, _super);
    function TypicalPriceIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TypicalPriceIndicator.prototype.get_yy = function () {
        return new TypicalPriceIndicatorStrategy();
    };
    Object.defineProperty(TypicalPriceIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    TypicalPriceIndicator.prototype.get_zb = function () {
        return TypicalPriceIndicator.$;
    };
    Object.defineProperty(TypicalPriceIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    TypicalPriceIndicator.$t = markType(TypicalPriceIndicator, 'TypicalPriceIndicator', StrategyBasedIndicator.$);
    return TypicalPriceIndicator;
}(StrategyBasedIndicator));
export { TypicalPriceIndicator };
